#!/bin/bash

# ============================================================================
# MIPS granule image BASH script
# 
# Through this script a color image is created from the given 1KM CREFL L1B
# file. The bands that must be used to create the color image from the CREFL 
# file, are passed to the script. 
# 
# Input parameters:
# satname - The satellite name. This should be one either one of the following:
#           terra, aqua, fy3a or fy3b.
# yeardate - Thear year, month and day value of the L1B file. It must be in the 
#            format of <year><month><day>, for example: 20091231.
# utctime - The UTC time of the L1B file. It must be in the format of <hour><minute>, 
#           for example: 0130.
# band_comb - The L1B band combination that must be used to create the granule 
#             color image. For MODIS it will be 01_04_03 and for MERSI it will 
#             be 03_02_01.
# ref 1km - The filesystem path to the 1KM L1B file. 
#
# Output:
# A JPEG image of the given 1KM L1B file, written to the directory specified by 
# $MIPS_GRAN_IMG_DIR.
# 
# Note: This script is used for both MODIS and MERSI 1KM L1B data.
# 
# Authors: Liam.Gumley@ssec.wisc.edu, Willem.Marais@ssec.wisc.edu
# Date: 07/22/2011
# ============================================================================

# # Check for MIPS_HOME environment variable
# if [ -z "$MIPS_HOME" ]; then
#     echo "Environment variable MIPS_HOME is not set"
#     exit 1
# fi
#
# # Check for MIPS_HOME environment variable
# if [ -z "$MIPS_GRAN_IMG_DIR" ]; then
#     echo "Environment variable MIPS_GRAN_IMG_DIR is not set"
#     exit 1
# fi

if [ $# -ne 4 ]; then
    echo "(ERROR) Usage:"
    echo "    "$(basename $0)" <idl base dir> <output file name> <band_comb> <ref 1km>"
    
    exit 1
fi

idl_base_dir_str=$1
output_fileP_str=$2
band_comb=$3
ref_1km=$4
band_red_nr=$(echo $band_comb | cut -d"_" -f 1)
band_grn_nr=$(echo $band_comb | cut -d"_" -f 2)
band_blu_nr=$(echo $band_comb | cut -d"_" -f 3)

# The IDL script which creates the granule images
# Construct the output PNG file name
cat > runidl << EOF
!path = strjoin(['$idl_base_dir_str:', !path])
make_granule_image_crefl,'$ref_1km','CorrRefl_$band_red_nr','CorrRefl_$band_grn_nr','CorrRefl_$band_blu_nr','$output_fileP_str'
exit
EOF

IDL_CMD=idl
$IDL_CMD runidl &> idl_output.txt

grep --ignore-case "Error" idl_output.txt &> /dev/null
if [ $? -eq 0 ]; then
    echo "(ERROR)[E11] Failed to create granule image of CREFL file $ref_1km"
    echo "========= IDL script ========="
    cat runidl
    echo "========= IDL output ========="
    cat idl_output.txt
    
    exit 1
fi

rm -f $out_png_granimg_path idl_output.txt runidl
